<?php

namespace FiloBlu\Flow\Console\Command;

use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class FetchCommand
 * @package FiloBlu\Flow\Console\Command
 */
class FetchCommand extends BaseCommand
{
    /**
     * @var string
     */
    const BUS_ARGUMENT = 'bus';

    /**
     *
     */
    protected function configure()
    {
        $this->setName('flow:fetch')
            ->setDescription('Retrieve files/data from remote source')
            ->setDefinition([
                new InputArgument(
                    self::BUS_ARGUMENT,
                    InputArgument::REQUIRED,
                    'Bus'
                ),
            ]);
    }

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     * @throws \Exception
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $this->ensureAreaCode($output);

        /** @var \FiloBlu\Flow\Cron\Fetch $cronModel */
        $cronModel = $this->fetchFactory->create();

        $bus = $input->getArgument(self::BUS_ARGUMENT);

        switch (intval($bus)) {
            case 1:
                $cronModel->executeBus1();
                break;
            case 2:
                $cronModel->executeBus2();
                break;
            case 3:
                $cronModel->executeBus3();
                break;
            case 4:
                $cronModel->executeBus4();
                break;
            default:
                throw new \InvalidArgumentException('Argument ' . self::BUS_ARGUMENT . ' must be one of 1,2,3,4');
        }

        $output->writeln('<info>Fetch executed on bus ' . $bus . '!</info>');
    }
}