<?php
/**
 * File:   Addtodefaultcategory.php
 * Author: Ernesto Minicone (napoli1890)
 * Date:   15/06/17
 * Time:   16.27
 */

namespace FiloBlu\Flow\Model\Actions\From;

/**
 * Class Addtodefaultcategory
 * @package FiloBlu\Flow\Model\Actions\From
 */
class Addtodefaultcategory extends Addtocategory
{
    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * Addtodefaultcategory constructor.
     * @param \FiloBlu\Flow\Helper\Product $helper_product
     * @param \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider
     * @param \Magento\Catalog\Model\CategoryFactory $categoryFactory
     * @param \Magento\Catalog\Model\ProductFactory $productFactory
     * @param \Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable $configurableProduct
     * @param \Magento\Store\Model\StoreManagerInterface $_storeManager
     */
    public function __construct(
        \FiloBlu\Flow\Helper\Product $helper_product,
        \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider,
        \Magento\Catalog\Model\CategoryFactory $categoryFactory,
        \Magento\Catalog\Model\ProductFactory $productFactory,
        \Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable $configurableProduct,
        \Magento\Store\Model\StoreManagerInterface $_storeManager
    )
    {
        $this->storeManager = $_storeManager;
        $this->_logger = $loggerProvider->getLogger();
        parent::__construct($helper_product, $loggerProvider, $categoryFactory, $productFactory, $configurableProduct);
    }

    /**
     * @param $product
     * @param $value
     * @param $storeId
     * @return bool|void
     * @throws \Exception
     */
    public function process($product, $value, $storeId)
    {
        $this->_logger->addInfo("Processing Action addtodefaultcategory for product: " . $product->getId());

        $storeManager = $this->storeManager;
        $stores = $storeManager->getStores();

        // For each store, get default category
        $default_categories =[];
        /** @var $store \Magento\Store\Model\Store */
        foreach ($stores as $store) {
            $default_categories[] = $store->getRootCategoryId();
        }

        // Filter categories
        $default_categories = array_unique(array_filter($default_categories));

        // Workaround on Addtocategory
        if (count($default_categories) == 1) {
            $default_categories[] = $default_categories[0];
        }

        // Create list of category ids
        if ($default_categories) {
            $value = implode("|", $default_categories);

            // Set value as $rootCatId | $rootCatId as workaround on Addtocategory
            parent::process($product, $value, $storeId);
            return;

        } else {
            throw new \Exception('No root categories configured on stores');
        }

    }

}